@@ -34,13 +34,13 @@ class Highlight_Config : public QWidget, public KonviSettingsPage, private Ui::H
 
         virtual bool hasChanged();
 
-    signals:
+    Q_SIGNALS:
         void modified();
 
-    protected slots:
+    protected Q_SLOTS:
         void highlightSelected(QTreeWidgetItem* item);
         void patternChanged(const QString& newPattern);
-        void regExpButtonClicked();
+        void notifyModeChanged(bool);
         void colorChanged(const QColor& newColor);
         void soundURLChanged(const QString& newURL);
         void autoTextChanged(const QString& newText);
