@@ -11,7 +11,6 @@
 */
 
 #include "settingsdialog.h"
-#include "configdialog.h"
 #include "preferences.h"
 #include "ui_chatwindowappearance_config.h"
 #include "connectionbehavior_config.h"
@@ -36,25 +35,32 @@
 
 #include <config-konversation.h>
 
+#include <KConfigDialog>
+#include <QIcon>
+#include <KLocalizedString>
+
 
 KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
-    KonviConfigDialog( parent, "settings", Preferences::self(), KPageDialog::Tree)
+    ConfigDialog( parent, QLatin1String("settings"), Preferences::self())
 {
-  m_modified = false;
-  QWidget *w = 0;
+  setFaceType(KPageDialog::Tree);
 
-  KPageWidgetItem *interfaceGroup = new KPageWidgetItem(new QWidget(this), i18n("Interface"));
-  interfaceGroup->setIcon(KIcon("preferences-desktop-theme"));
+  m_modified = false;
+
+  KPageWidgetItem* interfaceGroup = new KPageWidgetItem(new QWidget(this), i18n("Interface"));
+  interfaceGroup->setIcon(QIcon::fromTheme("preferences-desktop-theme"));
   KPageDialog::addPage(interfaceGroup);
 
-  KPageWidgetItem *behaviorGroup = new KPageWidgetItem(new QWidget(this), i18n("Behavior"));
-  behaviorGroup->setIcon(KIcon("configure"));
+  KPageWidgetItem* behaviorGroup = new KPageWidgetItem(new QWidget(this), i18n("Behavior"));
+  behaviorGroup->setIcon(QIcon::fromTheme("configure"));
   KPageDialog::addPage(behaviorGroup);
 
-  KPageWidgetItem *notificationGroup = new KPageWidgetItem(new QWidget(this), i18n("Notifications"));
-  notificationGroup->setIcon(KIcon("preferences-desktop-notification"));
+  KPageWidgetItem* notificationGroup = new KPageWidgetItem(new QWidget(this), i18n("Notifications"));
+  notificationGroup->setIcon(QIcon::fromTheme("preferences-desktop-notification"));
   KPageDialog::addPage(notificationGroup);
 
+  QWidget *w = 0;
+
   //Interface/Chat Window
   Ui::ChatWindowAppearance_Config confChatWindowAppearance;
   w = new QWidget();
@@ -62,46 +68,46 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   confChatWindowAppearance.kcfg_TimestampFormat->addItem("hh:mm");
   confChatWindowAppearance.kcfg_TimestampFormat->addItem("hh:mm:ss");
   confChatWindowAppearance.kcfg_TimestampFormat->addItem("h:m ap");
-  addPage(w, interfaceGroup, "view-list-text", i18n("Chat Window"));
+  konviAddSubPage(interfaceGroup, w, i18n("Chat Window"), QLatin1String("view-list-text"));
 
   //Interface/Themes
   m_confThemeWdg = new Theme_Config( this, "Theme" );
-  addPage ( m_confThemeWdg, interfaceGroup, "preferences-desktop-icons", i18n("Nicklist Themes") );
+  konviAddSubPage(interfaceGroup, m_confThemeWdg, i18n("Nicklist Themes"), QLatin1String("preferences-desktop-icons"));
   m_pages.append(m_confThemeWdg);
-  connect(m_confThemeWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  connect(m_confThemeWdg, &Theme_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Interface/Colors
   Ui::ColorsAppearance_Config confColorsAppearance;
   w = new QWidget();
   confColorsAppearance.setupUi(w);
-  addPage(w, interfaceGroup, "preferences-desktop-color", i18n("Colors"));
+  konviAddSubPage(interfaceGroup, w, i18n("Colors"), QLatin1String("preferences-desktop-color"));
 
   //Interface/Fonts
   Ui::FontAppearance_Config confFontAppearance;
   w = new QWidget();
   confFontAppearance.setupUi(w);
-  addPage(w, interfaceGroup, "preferences-desktop-font", i18n("Fonts"));
+  konviAddSubPage(interfaceGroup, w, i18n("Fonts"), QLatin1String("preferences-desktop-font"));
 
   //Interface/Quick Buttons
   m_confQuickButtonsWdg = new QuickButtons_Config( this, "QuickButtons" );
-  addPage ( m_confQuickButtonsWdg, interfaceGroup, "preferences-desktop-keyboard", i18n("Quick Buttons") );
+  konviAddSubPage(interfaceGroup, m_confQuickButtonsWdg, i18n("Quick Buttons"), QLatin1String("preferences-desktop-keyboard"));
   m_pages.append(m_confQuickButtonsWdg);
-  connect(m_confQuickButtonsWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  connect(m_confQuickButtonsWdg, &QuickButtons_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Interface/Tabs
   m_confTabBarWdg = new Tabs_Config( this, "TabBar" );
-  addPage ( m_confTabBarWdg, interfaceGroup, "tab-new", i18n("Tabs") );
+  konviAddSubPage(interfaceGroup, m_confTabBarWdg, i18n("Tabs"), QLatin1String("tab-new"));
 
   //Behavior/General
   Ui::GeneralBehavior_ConfigUI confGeneralBehavior;
   w = new QWidget();
   confGeneralBehavior.setupUi(w);
-  addPage( w, behaviorGroup, "configure", i18n("General") );
+  konviAddSubPage(behaviorGroup, w, i18n("General Behavior"), QLatin1String("configure"));
 
   //Behavior/Connection
   ConnectionBehavior_Config* confConnectionBehavior = new ConnectionBehavior_Config(this);
   confConnectionBehavior->setObjectName("ConnectionBehavior");
-  addPage(confConnectionBehavior, behaviorGroup, "network-connect", i18n("Connection"));
+  konviAddSubPage(behaviorGroup, confConnectionBehavior, i18n("Connection"), QLatin1String("network-connect"));
   m_pages.append(confConnectionBehavior);
 
   //Behaviour/Chat Window
@@ -111,30 +117,30 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   confChatwindowBehaviour.kcfg_ScrollbackMax->setSuffix(ki18np(" line", " lines"));
   confChatwindowBehaviour.kcfg_AutoWhoNicksLimit->setSuffix(ki18np(" nick", " nicks"));
   confChatwindowBehaviour.kcfg_AutoWhoContinuousInterval->setSuffix(ki18np(" second", " seconds"));
-  addPage(w, behaviorGroup, "view-list-text", i18n("Chat Window"));
+  konviAddSubPage(behaviorGroup, w, i18n("Chat Window"), QLatin1String("view-list-text"));
 
   //Behaviour/Nickname List
   m_confNicklistBehaviorWdg = new NicklistBehavior_Config( this, "NicklistBehavior" );
-  addPage ( m_confNicklistBehaviorWdg, behaviorGroup, "preferences-contact-list", i18n("Nickname List") );
-  connect(m_confNicklistBehaviorWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  konviAddSubPage(behaviorGroup, m_confNicklistBehaviorWdg, i18n("Nickname List"), QLatin1String("preferences-contact-list"));
+  connect(m_confNicklistBehaviorWdg, &NicklistBehavior_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
   m_pages.append(m_confNicklistBehaviorWdg);
 
   //Behaviour/Command Aliases
   m_confAliasWdg = new Alias_Config( this, "Alias" );
-  addPage ( m_confAliasWdg, behaviorGroup, "edit-rename", i18n("Command Aliases") );
+  konviAddSubPage(behaviorGroup, m_confAliasWdg, i18n("Command Aliases"), QLatin1String("edit-rename"));
   m_pages.append(m_confAliasWdg);
-  connect(m_confAliasWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  connect(m_confAliasWdg, &Alias_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Behaviour/Auto Replace
   m_confAutoreplaceWdg = new Autoreplace_Config( this, "Autoreplace" );
-  addPage ( m_confAutoreplaceWdg, behaviorGroup, "edit-rename", i18n("Auto Replace") );
+  konviAddSubPage(behaviorGroup, m_confAutoreplaceWdg, i18n("Auto Replace"), QLatin1String("edit-rename"));
   m_pages.append(m_confAutoreplaceWdg);
-  connect(m_confAutoreplaceWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  connect(m_confAutoreplaceWdg, &Autoreplace_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 
   //Behaviour/Ignore
   m_confIgnoreWdg = new Ignore_Config(this, "Ignore");
-  addPage ( m_confIgnoreWdg, behaviorGroup, "process-stop", i18n("Ignore") );
-  connect(m_confIgnoreWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  konviAddSubPage(behaviorGroup, m_confIgnoreWdg, i18nc("@title:tab", "Ignore"), QLatin1String("process-stop"));
+  connect(m_confIgnoreWdg, &Ignore_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
   m_pages.append(m_confIgnoreWdg);
 
   //Behaviour/Logging
@@ -142,54 +148,55 @@ KonviSettingsDialog::KonviSettingsDialog( QWidget *parent) :
   w = new QWidget();
   confLog.setupUi(w);
   confLog.kcfg_LogfilePath->setMode(KFile::Directory | KFile::ExistingOnly | KFile::LocalOnly);
-  addPage(w, behaviorGroup, "text-plain", i18n("Logging"));
+  konviAddSubPage(behaviorGroup, w, i18n("Logging"), QLatin1String("text-plain"));
 
-  m_confDCCWdg = new DCC_Config( this, "DCC" );
-  addPage ( m_confDCCWdg, behaviorGroup, "arrow-right-double", i18n("DCC") );
+  //DCC
+  m_confDCCWdg = new DCC_Config(this, "DCC");
+  konviAddSubPage(behaviorGroup, m_confDCCWdg, i18nc("@title:tab", "DCC"), QLatin1String("arrow-right-double"));
 
   //Notifications/Tab Bar
   Ui::TabNotifications_Config confTabNotifications;
   w = new QWidget();
   confTabNotifications.setupUi(w);
-  addPage(w, notificationGroup, "tab-new", i18n("Tabs"));
+  konviAddSubPage(notificationGroup, w, i18n("Tabs"), QLatin1String("tab-new"));
 
   //Notification/Highlighting
   m_confHighlightWdg = new Highlight_Config( this, "Highlight" );
-  addPage ( m_confHighlightWdg, notificationGroup, "flag-red", i18n("Highlight") );
-  connect(m_confHighlightWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  konviAddSubPage(notificationGroup, m_confHighlightWdg, i18n("Highlight"), QLatin1String("flag-red"));
+  connect(m_confHighlightWdg, &Highlight_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
   m_pages.append(m_confHighlightWdg);
 
   //Notification/Watched Nicknames
   Ui::WatchedNicknames_ConfigUI confWatchedNicks;
   w = new QWidget();
   confWatchedNicks.setupUi(w);
-  addPage(w, notificationGroup, "edit-find-user", i18n("Watched Nicknames"));
+  konviAddSubPage(notificationGroup, w, i18n("Watched Nicknames"), QLatin1String("edit-find-user"));
 
   //Notification/On Screen Display
   m_confOSDWdg = new OSD_Config( this, "OSD" );
-  addPage ( m_confOSDWdg, notificationGroup, "video-display", i18n("On Screen Display") );
+  konviAddSubPage(notificationGroup, m_confOSDWdg, i18n("On Screen Display"), QLatin1String("video-display"));
   //no modified connection needed - it's all kcfg widgets
   m_pages.append(m_confOSDWdg);
 
   //Notification/Warning Dialogs
   m_confWarningsWdg = new Warnings_Config( this, "Warnings" );
-  addPage ( m_confWarningsWdg, notificationGroup, "dialog-warning", i18n("Warning Dialogs") );
+  konviAddSubPage(notificationGroup, m_confWarningsWdg, i18n("Warning Dialogs"), QLatin1String("dialog-warning"));
   m_pages.append(m_confWarningsWdg);
-  connect(m_confWarningsWdg, SIGNAL(modified()), this, SLOT(modifiedSlot()));
+  connect(m_confWarningsWdg, &Warnings_Config::modified, this, &KonviSettingsDialog::modifiedSlot);
 }
 
 void KonviSettingsDialog::modifiedSlot()
 {
   // this is for the non KConfigXT parts to tell us, if the user actually changed
   // something or went back to the old settings
-// kDebug();
+// qDebug();
   m_modified = false;
   foreach (KonviSettingsPage *page, m_pages)
   {
     if (page->hasChanged())
     {
       m_modified = true;
-//      kDebug() << "modified!";
+//      qDebug() << "modified!";
       break;
     }
   }
@@ -208,7 +215,7 @@ void KonviSettingsDialog::updateSettings()
     page->saveSettings();
   }
   m_modified = false;
-  emit settingsChanged();
+  emit settingsChanged(QLatin1String("settings"));
 }
 
 void KonviSettingsDialog::updateWidgets()
@@ -229,12 +236,6 @@ void KonviSettingsDialog::updateWidgetsDefault()
   m_modified = true;
 }
 
-void KonviSettingsDialog::openWatchedNicknamesPage()
-{
-  // page index has been calculated in the constructor
-  setCurrentPage(m_watchedNicknamesPage);
-}
-
 // accessor method - will be used by KonviConfigDialog::updateButtons()
 bool KonviSettingsDialog::hasChanged()
 {
@@ -247,5 +248,5 @@ bool KonviSettingsDialog::isDefault()
   return true;
 }
 
-#include "settingsdialog.moc"
+
 
