@@ -23,20 +23,6 @@
 
 #include <config-konversation.h>
 
-#ifdef HAVE_BYTESWAP_H
-#   include <byteswap.h>
-#elif defined(HAVE_SYS_ENDIAN_H)
-#   include <sys/endian.h>
-#   define bswap_32(X) bswap32(X)
-#else
-#   if (defined(_MSC_VER) && (_MSC_VER > 1298))
-#       include <stdlib.h>
-#       define bswap_32(X) _byteswap_ulong(X)
-#   else
-#       define bswap_32(X) ( (((X)&0x000000FF)<<24) | (((X)&0xFF000000) >> 24) | (((X)&0x0000FF00) << 8) | (((X) &0x00FF0000) >> 8))
-#   endif
-#endif
-
 #include <QFileInfo>
 
 namespace Konversation
@@ -294,11 +280,6 @@ namespace Konversation
             return fileNameTmp;
         }
 
-        quint32 Transfer::intel(quint32 value)
-        {
-            return bswap_32(value);
-        }
-
         Transfer::Type Transfer::getType() const
         {
             return m_type;
