@@ -17,6 +17,14 @@
   (at your option) any later version.
 */
 
+#include <qglobal.h>
+
+#ifdef Q_OS_WIN
+// Prevent windows system header files from defining min/max as macros.
+#define NOMINMAX 1
+#include <winsock2.h>
+#endif
+
 #include "transferrecv.h"
 #include "dcccommon.h"
 #include "transfermanager.h"
@@ -187,7 +195,7 @@ namespace Konversation
                 m_ownIp = DccCommon::getOwnIp(Application::instance()->getConnectionManager()->getServerByConnectionId(m_connectionId));
             }
 
-            if (!KAuthorized::authorizeKAction("allow_downloading"))
+            if (!KAuthorized::authorizeAction("allow_downloading"))
             {
                 //note we have this after the initialisations so that item looks okay
                 //Do not have the rights to send the file.  Shouldn't have gotten this far anyway
@@ -584,7 +592,7 @@ namespace Konversation
 
                 if (error)
                 {
-                    server->appendMessageToFrontmost(i18nc("Universal Plug and Play", "UPnP"), i18n("Failed to forward port %1. Sending DCC request to remote user regardless.", QString::number(m_ownPort)), false);
+                    server->appendMessageToFrontmost(i18nc("Universal Plug and Play", "UPnP"), i18n("Failed to forward port %1. Sending DCC request to remote user regardless.", QString::number(m_ownPort)), QHash<QString, QString>(), false);
                 }
             }
 
@@ -630,7 +638,7 @@ namespace Konversation
 
             if ((quint64)m_transferringPosition != position)
             {
-                qDebug() << "remote responsed an unexpected position"<< endl
+                qDebug() << "remote responded with an unexpected position"<< endl
                     << "expected: " << m_transferringPosition << endl
                     << "remote response: " << position;
                 failed(i18n("Unexpected response from remote host"));
@@ -772,7 +780,7 @@ namespace Konversation
             //except for old mIRC versions, but they couldn't send or receive files over 4GB anyway.
             //Note: The resume and filesize are set via dcc send command and can be over 4GB
 
-            quint32 pos = intel((quint32)m_transferringPosition);
+            quint32 pos = htonl((quint32)m_transferringPosition);
 
             m_recvSocket->write((char*)&pos, 4);
             if (m_transferringPosition == (KIO::fileoffset_t)m_fileSize)
