@@ -11,11 +11,6 @@
 
 #include "whiteboardpaintarea.h"
 
-//is this still needed?
-#ifdef Q_CC_MSVC
-#    define _USE_MATH_DEFINES
-#endif
-
 #include <cmath>
 
 #include <QPainter>
