@@ -29,6 +29,7 @@ namespace Konversation
         setPort(settings.port());
         setPassword(settings.password());
         setSSLEnabled(settings.SSLEnabled());
+        setBypassProxy(settings.bypassProxy());
     }
 
     ServerSettings::ServerSettings(const QString& host)
@@ -39,10 +40,6 @@ namespace Konversation
         setBypassProxy(false);
     }
 
-    ServerSettings::~ServerSettings()
-    {
-    }
-
     bool ServerSettings::operator==(const ServerSettings& settings) const
     {
         if (m_host.toLower() == settings.host().toLower()
