@@ -27,14 +27,14 @@
 #include <QObject>
 #include <QPoint>
 
-#include <kdeversion.h>
+
 
 
 class Server;
 
 class QAction;
 
-class KMenu;
+class QMenu;
 
 
 class IrcContextMenus : public QObject
@@ -55,7 +55,6 @@ class IrcContextMenus : public QObject
             IgnoreNick, UnignoreNick,
             AddNotify, RemoveNotify,
             DccSend, StartDccChat, StartDccWhiteboard,
-            AddressbookNew, AddressbookChange, AddressbookEdit, AddressbookDelete, SendEmail
         };
 
         enum MenuOption
@@ -81,44 +80,49 @@ class IrcContextMenus : public QObject
         static void channelMenu(const QPoint& pos, Server* server, const QString& channel);
 
         static void nickMenu(const QPoint& pos, MenuOptions options, Server* server,
-            const QStringList& nicks, const QString& channel);
+            const QStringList& nicks, const QString& context);
         static void processNickAction(int actionId, Server* server, const QStringList& nicks,
-            const QString& channel);
+            const QString& context);
 
-#if !(QT_VERSION >= QT_VERSION_CHECK(4, 7, 0))
-        static void linkMenu(const QPoint& pos, const QString& link);
-#endif
         static void processLinkAction(int actionId, const QString& link);
 
+        static void topicHistoryMenu(const QPoint& pos, Server* server, const QString& text,
+            const QString& author);
 
-    protected slots:
-        void handleWebShortcutAction();
+
+    protected Q_SLOTS:
+        void processWebShortcutAction();
         void configureWebShortcuts();
+        void updateQuickButtonMenu();
 
 
     protected:
         explicit IrcContextMenus();
         friend class IrcContextMenusPrivate;
 
+        void setupQuickButtonMenu();
+        QMenu* m_quickButtonMenu;
+        bool shouldShowQuickButtonMenu();
+        static void processQuickButtonAction(QAction* action, Server* server, const QString& context,
+            const QStringList nicks = QStringList());
+
         void setupTextMenu();
-        KMenu* m_textMenu;
+        QMenu* m_textMenu;
         QAction* m_textCopyAction;
         QAction* m_textActionsSeparator;
         QList<QAction*> m_linkActions;
         void updateWebShortcutsMenu(const QString& selectedText);
-#if KDE_IS_VERSION(4, 5, 0)
-        KMenu* m_webShortcutsMenu;
-#endif
+        QMenu* m_webShortcutsMenu;
 
         void setupChannelMenu();
-        KMenu* m_channelMenu;
+        QMenu* m_channelMenu;
 
         void setupNickMenu();
-        KMenu* m_nickMenu;
+        QMenu* m_nickMenu;
         void createSharedBasicNickActions();
         QList<QAction*> m_sharedBasicNickActions;
-        KMenu* m_modesMenu;
-        KMenu* m_kickBanMenu;
+        QMenu* m_modesMenu;
+        QMenu* m_kickBanMenu;
         void createSharedNickSettingsActions();
         static void updateSharedNickSettingsActions(Server* server, const QStringList& nicks);
         QList<QAction*> m_sharedNickSettingsActions;
@@ -126,26 +130,18 @@ class IrcContextMenus : public QObject
         QAction* m_unignoreAction;
         QAction* m_addNotifyAction;
         QAction* m_removeNotifyAction;
-        static void updateAddressBookActions(Server* server, const QStringList& nicks);
-        KMenu* m_addressBookMenu;
-        QAction* m_addressBookNewAction;
-        QAction* m_addressBookChangeAction;
-        QAction* m_addressBookEditAction;
-        QAction* m_addressBookDeleteAction;
-        QAction* m_sendMailAction;
         void createSharedDccActions();
         QList<QAction*> m_sharedDccActions;
 
-#if !(QT_VERSION >= QT_VERSION_CHECK(4, 7, 0))
-        void setupLinkMenu();
-        KMenu* m_linkMenu;
-#endif
+        void setupTopicHistoryMenu();
+        QMenu* m_topicHistoryMenu;
+        QAction* m_queryTopicAuthorAction;
 
         inline QAction* createAction(ActionId id, const QString& text);
         inline QAction* createAction(ActionId id, const QIcon& icon);
         inline QAction* createAction(ActionId id, const QIcon& icon, const QString& text);
-        inline QAction* createAction(KMenu* menu, ActionId id, const QString& text);
-        inline QAction* createAction(KMenu* menu, ActionId id, const QIcon& icon,
+        inline QAction* createAction(QMenu* menu, ActionId id, const QString& text);
+        inline QAction* createAction(QMenu* menu, ActionId id, const QIcon& icon,
             const QString& text);
 
         static int extractActionId(QAction* action);
