@@ -12,23 +12,23 @@
 #ifndef IRCVIEWBOX_H
 #define IRCVIEWBOX_H
 
-#include <kvbox.h>
+#include <QWidget>
 
 class IRCView;
 class SearchBar;
 
-class IRCViewBox : public KVBox
+class IRCViewBox : public QWidget
 {
     Q_OBJECT
 
-        public:
+    public:
 
         explicit IRCViewBox(QWidget* parent);
         ~IRCViewBox();
 
         IRCView*   ircView() const;
 
-    public slots:
+    public Q_SLOTS:
 
         void slotSearch();
         void slotSearchNext();
